#!/bin/bash

# Created by WIPAT 2555-04-24
# updated by WIBOON 2562-11-25

if [ -z "$(id -nG|grep -w "root")" ] ; then
  echo "need root, or try: sudo sh $0"
  exit
fi

if [ -z "$1" ]; then
  sudo apt-get update -y
fi
sudo apt-get -y install freeradius
sudo apt-get -y install freeradius-utils
sudo apt-get -y install freeradius-mysql
sudo apt-get -y install freeradius-ldap 

codename=$(lsb_release -c | awk '{print $2}')
case ${codename} in
trusty) 
  #codename trusty (14.04)
  sudo apt-get -y install php5
  sudo apt-get -y install php5-imap 
  sudo apt-get -y install php5-cli
  sudo apt-get -y install php5-ldap
  sudo apt-get -y install php-soap
  ;;
xenial)
  #codename xenial (16.04)
  sudo apt-get -y install php7.0 
  sudo apt-get -y install php7.0-imap 
  sudo apt-get -y install php7.0-cli
  sudo apt-get -y install php7.0-ldap
  sudo apt-get -y install php7.0-soap
  ;;
bionic)
  #codename bionic (18.04)
  sudo apt-get -y install php7.2 
  sudo apt-get -y install php7.2-imap 
  sudo apt-get -y install php7.2-cli
  sudo apt-get -y install php7.2-ldap
  sudo apt-get -y install php7.2-soap
  ;;
focal)
  #codename focal (20.04)
  sudo apt-get -y install php7.4 
  sudo apt-get -y install php7.4-imap 
  sudo apt-get -y install php7.4-cli
  sudo apt-get -y install php7.4-ldap
  sudo apt-get -y install php7.4-soap
  ;;
*)
  #codename others
  sudo apt-get -y install php 
  sudo apt-get -y install php-imap 
  sudo apt-get -y install php-cli
  sudo apt-get -y install php-ldap
  sudo apt-get -y install php-soap
esac

sudo apt-get -y install ldap-utils
sudo apt-get -y install expect
sudo apt-get -y install gawk
sudo apt-get -y install whois
sudo apt-get -y install dialog

MY_DIR=$(pwd)
SRC_DIR="${MY_DIR}/trunk/"
DST_DIR="/"

freeradiusversion=$(freeradius -v | grep -i version | head -1 | awk '{print $4}' | cut -d. -f1,2)
case ${freeradiusversion} in
3.?)
  #3.x remove some files from trunk
  sudo rm -f ${SRC_DIR}/etc/freeradius/myusers
  sudo rm -f ${SRC_DIR}/etc/freeradius/clients.conf
  sudo rm -rf ${SRC_DIR}/etc/freeradius/modules
  sudo rm -rf ${SRC_DIR}/etc/freeradius/sites-available
  ;;
2.?)
  #2.x remove some files from trunk
  sudo rm -rf ${SRC_DIR}/etc/freeradius/3.*
  ;;
*)
  #3.x up remove some files from trunk
  sudo rm -f ${SRC_DIR}/etc/freeradius/myusers
  sudo rm -f ${SRC_DIR}/etc/freeradius/clients.conf
  sudo rm -rf ${SRC_DIR}/etc/freeradius/modules
  sudo rm -rf ${SRC_DIR}/etc/freeradius/sites-available
  ;;
esac

case ${codename} in
trusty) 
	# upstart
	;;
xenial)
	# upstart
	;;
bionic)
	# systemd
	sudo systemctl enable freeradius
	;;
focal)
	# systemd
	sudo systemctl enable freeradius
	;;
*)
	# systemd
	sudo systemctl enable freeradius
	;;
esac

find ${SRC_DIR} -type d| while read LINE ; do
  TARGET=$(echo ${LINE}|sed "s;${SRC_DIR};${DST_DIR};")
  if [ ! -d "${TARGET}" ] ; then
    mkdir ${TARGET}
  fi
done
find ${SRC_DIR} -type f| while read LINE ; do
  TARGET=$(echo ${LINE}|sed "s;${SRC_DIR};${DST_DIR};")
  if [ -e "${TARGET}" ] ; then
    if [ -z "$(diff -q ${LINE} ${TARGET})" ] ; then
      continue
    fi 
    INFO=$(ls -clQ --time-style=long-iso ${TARGET})
    CTIME=$(echo ${INFO}|awk '{ print $6"-"$7 }')
    NAME=$(echo "${TARGET}_${CTIME}")
    cp -v ${TARGET} ${NAME}
  fi
  cp -v ${LINE} ${TARGET}
done

sudo cp -f ${MY_DIR}/version.txt /etc/freeradius

sudo chown -R freerad:freerad /etc/freeradius

#
# add dialog by pom (wisit)
url1=ftp.psu.ac.th/pub/psu12-sritrang/download/scripts
dir1=/root/scripts
if [ ! -d $dir1 ] ;then
   sudo mkdir $dir1
fi
sudo wget -N $url1/editcheck-ad-ldap.sh -P $dir1
sudo wget -N $url1/editclientsconf.sh -P $dir1
sudo wget -N $url1/editimap-authen.sh -P $dir1
sudo wget -N $url1/editldapdata.sh -P $dir1
sudo wget -N $url1/editmy-authen.sh -P $dir1
sudo wget -N $url1/editpreblacklist.sh -P $dir1
sudo wget -N $url1/editviplist.sh -P $dir1
sudo wget -N $url1/restartradiusserver.sh -P $dir1
sudo wget -N $url1/freeradiusmanagement.sh -P $dir1
sudo wget -N $url1/testfreeradiususer.sh -P $dir1
sudo ln -s /root/scripts/freeradiusmanagement.sh /root/freeradiusmanagement.sh
#
# update file /etc/ldap.conf
#
MYINSTALL="#PSU-radius-2559-04-29"
MYFILE="/etc/ldap/ldap.conf"
if [ -z "$(grep "${MYINSTALL}" ${MYFILE})" ] ; then
  echo "${MYINSTALL}" | sudo tee -a ${MYFILE}
  (echo 'TLS_REQCERT never') | sudo tee -a ${MYFILE}
fi 
# Finish
echo "PSU-radius installation is finished."

